==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S69339366de6cc19b593990f5cc1196a6.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#include <OpenTransport.h>

#include <OpenTptInternet.h>

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S02018c21aae4cfd793a8f80f191dec71.h"

#include "S69339366de6cc19b593990f5cc1196a6.h"

#include "Sa7f564241028472364c4b422004927d3.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"
 S57c2877c1d84c4b49f3289657deca65c void Saaf5cac29f5f79494b75f599a5843c4d(void* S4af7d6a9c65b4fcbbf6d9974088fdfe0, 
S0741a51513781198fa0222eb4e3f341b Sc13367945d5d4c91047b3b50234aa7ab, Sd45286151d01467b0cc5e8438f8cb876 
Sb4a88417b3d0170d754c647c30b7216a, void* S2dccd1ab3e03990aea77359831c85ca2); S9306f7b874c0902f0015f766b71c4b8b::S9306f7b874c0902f0015f766b71c4b8b(Se812b5a98988bad1d5b8df118cb6cc7f 
&S8c9a70dc1e604715e475d87430ba602d, S16862cc22937746fc7908ff73ebf8229 Sfe3838c7c11aa406dd956566e17360d5) 
: Saca418ab700fd41fea0a83282df12687(S8c9a70dc1e604715e475d87430ba602d) { S818f9c45cfa30eeff277ef38bcbe9910 
= Sfe3838c7c11aa406dd956566e17360d5; S00ce06fa9365b55a063506933582e5b0 = false; 
#error implement remoteClose
 } S9306f7b874c0902f0015f766b71c4b8b::S9306f7b874c0902f0015f766b71c4b8b(Se812b5a98988bad1d5b8df118cb6cc7f 
&S8c9a70dc1e604715e475d87430ba602d, const char *Sc7ab55c385ea800f44b02840bdd351a7, unsigned short Sa6120072b1b1ee42a239c3cf87163151, 
bool Se6d056471be39d6a77b99dcae00a07a4) : Saca418ab700fd41fea0a83282df12687(S8c9a70dc1e604715e475d87430ba602d) 
{ Saf6c0c3c714d1f5ab0d299b2cbf50060(S62390332d50bfebdc49b35c401c29c09(S4d682ec4eed27c53849758bc13b6e179)); 
S0897acf49c7c1ea9f76efe59187aa046 = Sc7ab55c385ea800f44b02840bdd351a7; S23113671780610f75a31146b841a132a 
= Sa6120072b1b1ee42a239c3cf87163151; Sa6a822293cfe9c25374cf2267d45d856 S56bd7107802ebe56c6918992f0608ec6; 
S7d10ced7ca35fa173032f6f993b13d79 Sd19f37366e84e96a201fd0db5696ad6e; Saac93e8f7c547462334c87fc65cbe870 
S064aa6be5148fd86e63ff1a264a6b449; 
#if TARGET_API_MAC_CARBON
 S818f9c45cfa30eeff277ef38bcbe9910 = S60fc422ebd17814890f1684c286322cb(S7a81a4b68b07ad82a157bae27c918707(Sbbff665cee7b9ff4aeb6caf33257d0ec), 
0, S852438d026c018c4307b916406f98c62, &S56bd7107802ebe56c6918992f0608ec6, NULL); 
#else
 S818f9c45cfa30eeff277ef38bcbe9910 = Scbf5aa23a0111c2598fbb0c5543a9a55(S7a81a4b68b07ad82a157bae27c918707(Sbbff665cee7b9ff4aeb6caf33257d0ec), 
0, S852438d026c018c4307b916406f98c62, &S56bd7107802ebe56c6918992f0608ec6); 
#endif
 if (S56bd7107802ebe56c6918992f0608ec6 != S76fde27a5f2944bbcee2c94603d26a9f) { Scb5e100e5a9a3e7f6d1fd97512215282 
= true; if (Se6d056471be39d6a77b99dcae00a07a4) { Sdc89a30d4c97fd8b60329797e2883ba8("{ERROR_OPEN_TCPIP_ENDPOINT}"); 
} else return; } S56bd7107802ebe56c6918992f0608ec6 = S66d865bc37ec2e3179f06b7ff0fe27af(S818f9c45cfa30eeff277ef38bcbe9910); 
if (S56bd7107802ebe56c6918992f0608ec6 != S76fde27a5f2944bbcee2c94603d26a9f) { Scb5e100e5a9a3e7f6d1fd97512215282 
= true; if (Se6d056471be39d6a77b99dcae00a07a4) { Sdc89a30d4c97fd8b60329797e2883ba8("{ERROR_SET_TCPIP_ENDPOINT_SYNCRONOUS}"); 
} else return; }  S56bd7107802ebe56c6918992f0608ec6 = S8197f113f3cb3aebb4967bc602c85f85(S818f9c45cfa30eeff277ef38bcbe9910, 
S852438d026c018c4307b916406f98c62, S852438d026c018c4307b916406f98c62); if (S56bd7107802ebe56c6918992f0608ec6 
!= S76fde27a5f2944bbcee2c94603d26a9f) { Scb5e100e5a9a3e7f6d1fd97512215282 = true; if (Se6d056471be39d6a77b99dcae00a07a4) 
{ S5f9c1850b588b053c5688b8461d7ace4(S0897acf49c7c1ea9f76efe59187aa046, S735ea79b91c0fd264244146d58553488(S4d682ec4eed27c53849758bc13b6e179, 
S23113671780610f75a31146b841a132a), "{ERROR_BIND_ENDPOINT}"); } else return; }  Se9ec1f33cf0cc5b8e785a5ca0b29923f(&Sd19f37366e84e96a201fd0db5696ad6e, 
sizeof(S7d10ced7ca35fa173032f6f993b13d79)); Sd19f37366e84e96a201fd0db5696ad6e.S3ef9a0d7fab5d2bcabf0978c0a35244e.Scb7e52b21171fb9a53b498202607f0bd 
= (Sb31df9c476d20e85ff898121efe11b5a *) &S064aa6be5148fd86e63ff1a264a6b449; Sd19f37366e84e96a201fd0db5696ad6e.S3ef9a0d7fab5d2bcabf0978c0a35244e.Sf5a8e923f8cd24b56b3bab32358cc58a 
= S1aa139794f9a39d6cf3f1900b88c349a(&S064aa6be5148fd86e63ff1a264a6b449, (char *) (S0897acf49c7c1ea9f76efe59187aa046 
+ ":" + S735ea79b91c0fd264244146d58553488(S4d682ec4eed27c53849758bc13b6e179, S23113671780610f75a31146b841a132a)).c_str()); 
S56bd7107802ebe56c6918992f0608ec6 = S7e72dbfd8050c4016fdd89274d0f6e48(S818f9c45cfa30eeff277ef38bcbe9910, 
&Sd19f37366e84e96a201fd0db5696ad6e, S852438d026c018c4307b916406f98c62); if (S56bd7107802ebe56c6918992f0608ec6 
!= S76fde27a5f2944bbcee2c94603d26a9f) { Scb5e100e5a9a3e7f6d1fd97512215282 = true; if (Se6d056471be39d6a77b99dcae00a07a4) 
{ S5f9c1850b588b053c5688b8461d7ace4(S0897acf49c7c1ea9f76efe59187aa046, S735ea79b91c0fd264244146d58553488(S4d682ec4eed27c53849758bc13b6e179, 
S23113671780610f75a31146b841a132a), "{ERROR_CONNECT_ENDPOINT}"); } else return; } }  unsigned long S9306f7b874c0902f0015f766b71c4b8b::S4e2021bf4cf7828bbbd067a23d0145ff(unsigned 
char *S7f2db423a49b305459147332fb01cf87, unsigned long Sf5a8e923f8cd24b56b3bab32358cc58a) { while (1) 
{ int Sd871906e18d7e876e6494103da4beebd = S44453a02c6629cef11a41c00cf21e00e(S818f9c45cfa30eeff277ef38bcbe9910, 
(char *) S7f2db423a49b305459147332fb01cf87, Sf5a8e923f8cd24b56b3bab32358cc58a, 0); if (Sd871906e18d7e876e6494103da4beebd 
> 0) return Sd871906e18d7e876e6494103da4beebd; if (Sd871906e18d7e876e6494103da4beebd == S57fa93a58c55564402abeb6bff4e8616) 
{ Scf1a9881e386c8e70e7eef180d4e1e5a(); continue; } if (Sd871906e18d7e876e6494103da4beebd < 0) return 
0; } } unsigned long S9306f7b874c0902f0015f766b71c4b8b::Scc7e96e085b9d6b3ef9a1c58a8b2e49a(const unsigned 
char *S7f2db423a49b305459147332fb01cf87, unsigned long Sf5a8e923f8cd24b56b3bab32358cc58a) { if (!open) 
S2412a951f8feceb992d7ef30108bfb06(); long Sae887c29c29f5ca22060dcb00e0fb057 = S97a84a6f8dd09b7e23e88c63183e66d4(S818f9c45cfa30eeff277ef38bcbe9910, 
(char *) S7f2db423a49b305459147332fb01cf87, Sf5a8e923f8cd24b56b3bab32358cc58a, 0); if (Sae887c29c29f5ca22060dcb00e0fb057 
== S7694a4f901d6f2052f2f103428503280) Sae887c29c29f5ca22060dcb00e0fb057 = 0; return Sae887c29c29f5ca22060dcb00e0fb057; 
} void S9306f7b874c0902f0015f766b71c4b8b::Sd3d2e617335f08df83599665eef8a418(void) { Sa6a822293cfe9c25374cf2267d45d856 
S56bd7107802ebe56c6918992f0608ec6 = S37f9319bf46a463d4a643aa5e10c769c(S818f9c45cfa30eeff277ef38bcbe9910); 
S56bd7107802ebe56c6918992f0608ec6 = S0d193e3b62b38c14998b12b91f2516d2(S818f9c45cfa30eeff277ef38bcbe9910); 
open = false; } bool S9306f7b874c0902f0015f766b71c4b8b::Sd0a72a0881be272890b99f92ec69c29f(void) { size_t 
S4d191739f5b50f7cb1c96868103843da; S8915e86f624af0075caf6ef1ce212319(S818f9c45cfa30eeff277ef38bcbe9910, 
&S4d191739f5b50f7cb1c96868103843da); return (S4d191739f5b50f7cb1c96868103843da != 0); }

==> sawmill6.5b3_crypt_src.tar.gz: sawmill-6.5b3/S69339366de6cc19b593990f5cc1196a6.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include <OpenTransport.h>

#include <OpenTptInternet.h>

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S02018c21aae4cfd793a8f80f191dec71.h"

#include "S69339366de6cc19b593990f5cc1196a6.h"

#include "Sa7f564241028472364c4b422004927d3.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"
 S57c2877c1d84c4b49f3289657deca65c void Saaf5cac29f5f79494b75f599a5843c4d(void* S4af7d6a9c65b4fcbbf6d9974088fdfe0, 
S0741a51513781198fa0222eb4e3f341b Sc13367945d5d4c91047b3b50234aa7ab, Sd45286151d01467b0cc5e8438f8cb876 
Sb4a88417b3d0170d754c647c30b7216a, void* S2dccd1ab3e03990aea77359831c85ca2); S9306f7b874c0902f0015f766b71c4b8b::S9306f7b874c0902f0015f766b71c4b8b(Se812b5a98988bad1d5b8df118cb6cc7f 
&S8c9a70dc1e604715e475d87430ba602d, S16862cc22937746fc7908ff73ebf8229 Sfe3838c7c11aa406dd956566e17360d5) 
: Saca418ab700fd41fea0a83282df12687(S8c9a70dc1e604715e475d87430ba602d) { S818f9c45cfa30eeff277ef38bcbe9910 
= Sfe3838c7c11aa406dd956566e17360d5; S00ce06fa9365b55a063506933582e5b0 = false; } S9306f7b874c0902f0015f766b71c4b8b::S9306f7b874c0902f0015f766b71c4b8b(Se812b5a98988bad1d5b8df118cb6cc7f 
&S8c9a70dc1e604715e475d87430ba602d, const char *Sc7ab55c385ea800f44b02840bdd351a7, unsigned short Sa6120072b1b1ee42a239c3cf87163151, 
bool Se6d056471be39d6a77b99dcae00a07a4) : Saca418ab700fd41fea0a83282df12687(S8c9a70dc1e604715e475d87430ba602d) 
{ Saf6c0c3c714d1f5ab0d299b2cbf50060(S62390332d50bfebdc49b35c401c29c09(S4d682ec4eed27c53849758bc13b6e179)); 
S0897acf49c7c1ea9f76efe59187aa046 = Sc7ab55c385ea800f44b02840bdd351a7; S23113671780610f75a31146b841a132a 
= Sa6120072b1b1ee42a239c3cf87163151; Sa6a822293cfe9c25374cf2267d45d856 S56bd7107802ebe56c6918992f0608ec6; 
S7d10ced7ca35fa173032f6f993b13d79 Sd19f37366e84e96a201fd0db5696ad6e; Saac93e8f7c547462334c87fc65cbe870 
S064aa6be5148fd86e63ff1a264a6b449; 
#if TARGET_API_MAC_CARBON
 S818f9c45cfa30eeff277ef38bcbe9910 = S60fc422ebd17814890f1684c286322cb(S7a81a4b68b07ad82a157bae27c918707(Sbbff665cee7b9ff4aeb6caf33257d0ec), 
0, S852438d026c018c4307b916406f98c62, &S56bd7107802ebe56c6918992f0608ec6, NULL); 
#else
 S818f9c45cfa30eeff277ef38bcbe9910 = Scbf5aa23a0111c2598fbb0c5543a9a55(S7a81a4b68b07ad82a157bae27c918707(Sbbff665cee7b9ff4aeb6caf33257d0ec), 
0, S852438d026c018c4307b916406f98c62, &S56bd7107802ebe56c6918992f0608ec6); 
#endif
 if (S56bd7107802ebe56c6918992f0608ec6 != S76fde27a5f2944bbcee2c94603d26a9f) { Scb5e100e5a9a3e7f6d1fd97512215282 
= true; if (Se6d056471be39d6a77b99dcae00a07a4) { Sdc89a30d4c97fd8b60329797e2883ba8("{ERROR_OPEN_TCPIP_ENDPOINT}"); 
} else return; } S56bd7107802ebe56c6918992f0608ec6 = S66d865bc37ec2e3179f06b7ff0fe27af(S818f9c45cfa30eeff277ef38bcbe9910); 
if (S56bd7107802ebe56c6918992f0608ec6 != S76fde27a5f2944bbcee2c94603d26a9f) { Scb5e100e5a9a3e7f6d1fd97512215282 
= true; if (Se6d056471be39d6a77b99dcae00a07a4) { Sdc89a30d4c97fd8b60329797e2883ba8("{ERROR_SET_TCPIP_ENDPOINT_SYNCRONOUS}"); 
} else return; }  S56bd7107802ebe56c6918992f0608ec6 = S8197f113f3cb3aebb4967bc602c85f85(S818f9c45cfa30eeff277ef38bcbe9910, 
S852438d026c018c4307b916406f98c62, S852438d026c018c4307b916406f98c62); if (S56bd7107802ebe56c6918992f0608ec6 
!= S76fde27a5f2944bbcee2c94603d26a9f) { Scb5e100e5a9a3e7f6d1fd97512215282 = true; if (Se6d056471be39d6a77b99dcae00a07a4) 
{ S5f9c1850b588b053c5688b8461d7ace4(S0897acf49c7c1ea9f76efe59187aa046, S735ea79b91c0fd264244146d58553488(S4d682ec4eed27c53849758bc13b6e179, 
S23113671780610f75a31146b841a132a), "{ERROR_BIND_ENDPOINT}"); } else return; }  Se9ec1f33cf0cc5b8e785a5ca0b29923f(&Sd19f37366e84e96a201fd0db5696ad6e, 
sizeof(S7d10ced7ca35fa173032f6f993b13d79)); Sd19f37366e84e96a201fd0db5696ad6e.S3ef9a0d7fab5d2bcabf0978c0a35244e.Scb7e52b21171fb9a53b498202607f0bd 
= (Sb31df9c476d20e85ff898121efe11b5a *) &S064aa6be5148fd86e63ff1a264a6b449; Sd19f37366e84e96a201fd0db5696ad6e.S3ef9a0d7fab5d2bcabf0978c0a35244e.Sf5a8e923f8cd24b56b3bab32358cc58a 
= S1aa139794f9a39d6cf3f1900b88c349a(&S064aa6be5148fd86e63ff1a264a6b449, (char *) (S0897acf49c7c1ea9f76efe59187aa046 
+ ":" + S735ea79b91c0fd264244146d58553488(S4d682ec4eed27c53849758bc13b6e179, S23113671780610f75a31146b841a132a)).c_str()); 
S56bd7107802ebe56c6918992f0608ec6 = S7e72dbfd8050c4016fdd89274d0f6e48(S818f9c45cfa30eeff277ef38bcbe9910, 
&Sd19f37366e84e96a201fd0db5696ad6e, S852438d026c018c4307b916406f98c62); if (S56bd7107802ebe56c6918992f0608ec6 
!= S76fde27a5f2944bbcee2c94603d26a9f) { Scb5e100e5a9a3e7f6d1fd97512215282 = true; if (Se6d056471be39d6a77b99dcae00a07a4) 
{ S5f9c1850b588b053c5688b8461d7ace4(S0897acf49c7c1ea9f76efe59187aa046, S735ea79b91c0fd264244146d58553488(S4d682ec4eed27c53849758bc13b6e179, 
S23113671780610f75a31146b841a132a), "{ERROR_CONNECT_ENDPOINT}"); } else return; } }  unsigned long S9306f7b874c0902f0015f766b71c4b8b::S4e2021bf4cf7828bbbd067a23d0145ff(unsigned 
char *S7f2db423a49b305459147332fb01cf87, unsigned long Sf5a8e923f8cd24b56b3bab32358cc58a) { while (true) 
{ int Sd871906e18d7e876e6494103da4beebd = S44453a02c6629cef11a41c00cf21e00e(S818f9c45cfa30eeff277ef38bcbe9910, 
(char *) S7f2db423a49b305459147332fb01cf87, Sf5a8e923f8cd24b56b3bab32358cc58a, 0); if (Sd871906e18d7e876e6494103da4beebd 
> 0) return Sd871906e18d7e876e6494103da4beebd; if (Sd871906e18d7e876e6494103da4beebd == S57fa93a58c55564402abeb6bff4e8616) 
{ Scf1a9881e386c8e70e7eef180d4e1e5a();  int S12470fe406d44017d96eab37dd65fc14 = S4d49599e90356964988e3d7a6fc4496a(S818f9c45cfa30eeff277ef38bcbe9910); 
if ((S12470fe406d44017d96eab37dd65fc14 == S9a4eba4659af3fba7a99728f43e655dc) || (S12470fe406d44017d96eab37dd65fc14 
== S31419a05c4cdc01b7ab1d2ddf5751ccb) || (S12470fe406d44017d96eab37dd65fc14 == S6092ef72566e2e4ff5fbcf88d2963857)) 
S00ce06fa9365b55a063506933582e5b0 = true; continue; } if (Sd871906e18d7e876e6494103da4beebd < 0) {  
S00ce06fa9365b55a063506933582e5b0 = true; return 0; }  }  }  unsigned long S9306f7b874c0902f0015f766b71c4b8b::Scc7e96e085b9d6b3ef9a1c58a8b2e49a(const 
unsigned char *S7f2db423a49b305459147332fb01cf87, unsigned long Sf5a8e923f8cd24b56b3bab32358cc58a) { 
if (!open) S2412a951f8feceb992d7ef30108bfb06(); long Sae887c29c29f5ca22060dcb00e0fb057 = S97a84a6f8dd09b7e23e88c63183e66d4(S818f9c45cfa30eeff277ef38bcbe9910, 
(char *) S7f2db423a49b305459147332fb01cf87, Sf5a8e923f8cd24b56b3bab32358cc58a, 0); if (Sae887c29c29f5ca22060dcb00e0fb057 
== S7694a4f901d6f2052f2f103428503280) Sae887c29c29f5ca22060dcb00e0fb057 = 0; return Sae887c29c29f5ca22060dcb00e0fb057; 
} void S9306f7b874c0902f0015f766b71c4b8b::Sd3d2e617335f08df83599665eef8a418(void) { Sa6a822293cfe9c25374cf2267d45d856 
S56bd7107802ebe56c6918992f0608ec6 = S37f9319bf46a463d4a643aa5e10c769c(S818f9c45cfa30eeff277ef38bcbe9910); 
S56bd7107802ebe56c6918992f0608ec6 = S0d193e3b62b38c14998b12b91f2516d2(S818f9c45cfa30eeff277ef38bcbe9910); 
open = false; } bool S9306f7b874c0902f0015f766b71c4b8b::Sd0a72a0881be272890b99f92ec69c29f(void) { size_t 
S4d191739f5b50f7cb1c96868103843da; S8915e86f624af0075caf6ef1ce212319(S818f9c45cfa30eeff277ef38bcbe9910, 
&S4d191739f5b50f7cb1c96868103843da); return (S4d191739f5b50f7cb1c96868103843da != 0); }
